# telegraf-collector

A Helm chart for Telegraf Collector with VMware additions.

## Additional Information

This tool can be used to enable collection of metrics for identification of service-to-service traffic to
Secure State.

## Installing the Chart

To install the chart with the release name `telegraf-collector`:

The available Chart options are listed further down. Refer to this list for required and optional parameters.

### Connecting to the k8s-collector

Once the `telegraf-collector` is installed, a Kubernetes Service will be available that points to the
`telegraf-collector` pods.

For the `k8s-collector` to successfully poll the `telegraf-collector, you must add the following `extraEnvVars` to your
`k8s-collector`'s `values.yaml` file

```console
collector:
  extraEnvVars:
    NETWORK_MAP_METRICS_ENDPOINT: http://aria-telegraf-collector.chss-collector:4317/metrics
```

The above URL is in the form `SERVICE-NAME.NAMESPACE` and specifies the port `4317` (the default) to query for network
metrics at.

After you have updated your `values.yaml` file, you can use the `helm upgrade` command to refresh the configuration
of the `k8s-collector`. For example,

```console
helm upgrade aria-k8s-collector ./charts/k8s-collector/ \
  --namespace ${NAMESPACE-chss-collector} \
  --values ${VALUES_FILE} \
  --set config.clusterManaged=false \
  --set config.clusterCloudProvider=AWS
```

Note: Your values and `--set` arguments may be different from what is show above.

### Helm 3.8+

Helm 3.8 adopted a different distribution model for Charts. OCI image registries are the preferred method of
distributing Charts going forward.

```console
$ helm install telegraf-collector oci://projects.registry.vmware.com/securestate/helm-charts/telegraf-collector
```

### Helm <= 3.7

Helm versions <= 3.7 support distribution from Chart Repositories.

```console
$ helm repo add vmware-securestate https://projects.registry.vmware.com/chartrepo/securestate
$ helm install telegraf-collector vmware-securestate/telegraf-collector
```

## Upgrading

No upgrades are available at this time.

## Uninstall

Note: when you uninstall the Collector, configured clusters will remain untouched in the Secure State UI.

```console
$ helm uninstall <RELEASE NAME> -n <YOUR NAMESPACE>
```

## Requirements

Kubernetes: `>=1.18.0-0`

## Values

| Key | Type | Default | Description |
|-----|------|---------|-------------|
| global.enabled | bool | `true` |  |
| global.imagePullSecrets | list | `[]` |  |
| telegraf.affinity | string | `"podAntiAffinity:\n  requiredDuringSchedulingIgnoredDuringExecution:\n    - labelSelector:\n        matchLabels:\n          app.kubernetes.io/name: {{ template \"collector.name\" . }}\n          app.kubernetes.io/instance: \"{{ .Release.Name }}\"\n          component: telegraf-collector\n      topologyKey: kubernetes.io/hostname\n"` |  |
| telegraf.agent.collectionJitter | string | `"3s"` |  |
| telegraf.agent.debug | bool | `true` |  |
| telegraf.agent.flushInterval | string | `"20s"` |  |
| telegraf.agent.flushJitter | string | `"3s"` |  |
| telegraf.agent.metricBatchSize | int | `10000` |  |
| telegraf.agent.metricBufferLimit | int | `5000000` |  |
| telegraf.annotations | object | `{}` |  |
| telegraf.emptyDir.sizeLimit | string | `""` |  |
| telegraf.enabled | bool | `true` |  |
| telegraf.extraArgs[0] | string | `"--config"` |  |
| telegraf.extraArgs[1] | string | `"/config/telegraf.conf"` |  |
| telegraf.extraArgs[2] | string | `"--config-directory"` |  |
| telegraf.extraArgs[3] | string | `"/config-extra/"` |  |
| telegraf.extraContainers | string | `nil` |  |
| telegraf.extraInitContainers | string | `nil` |  |
| telegraf.extraLabels | object | `{}` |  |
| telegraf.extraTelegrafConfig | object | `{}` |  |
| telegraf.image.imagePullSecrets | list | `[]` |  |
| telegraf.image.pullPolicy | string | `"IfNotPresent"` |  |
| telegraf.image.repository | string | `"projects.registry.vmware.com/aria/telegraf"` |  |
| telegraf.image.tag | string | `"236-d138846-2013289317"` |  |
| telegraf.initContainers | list | `[]` |  |
| telegraf.labels | object | `{}` |  |
| telegraf.livenessProbe.enabled | bool | `true` |  |
| telegraf.livenessProbe.initialDelaySeconds | int | `15` |  |
| telegraf.livenessProbe.periodSeconds | int | `20` |  |
| telegraf.livenessProbe.port | int | `13133` |  |
| telegraf.minReadySeconds | int | `5` |  |
| telegraf.networkPolicy.egress | list | `[]` |  |
| telegraf.networkPolicy.enabled | bool | `false` |  |
| telegraf.nodeSelector | object | `{}` |  |
| telegraf.persistentVolume.accessModes[0] | string | `"ReadWriteOnce"` |  |
| telegraf.persistentVolume.annotations | object | `{}` |  |
| telegraf.persistentVolume.enabled | bool | `false` |  |
| telegraf.persistentVolume.existingClaim | string | `""` |  |
| telegraf.persistentVolume.mountPath | string | `"/opt/aria-creds-telegraf"` |  |
| telegraf.persistentVolume.size | string | `"1Gi"` |  |
| telegraf.persistentVolume.subPath | string | `""` |  |
| telegraf.postStart | list | `[]` |  |
| telegraf.preStop | list | `[]` |  |
| telegraf.priorityClassName | string | `""` |  |
| telegraf.progressDeadlineSeconds | int | `120` |  |
| telegraf.readinessProbe.enabled | bool | `true` |  |
| telegraf.readinessProbe.initialDelaySeconds | int | `5` |  |
| telegraf.readinessProbe.periodSeconds | int | `5` |  |
| telegraf.readinessProbe.port | int | `13133` |  |
| telegraf.replicas | int | `1` |  |
| telegraf.resources.limits.cpu | string | `"1000m"` |  |
| telegraf.resources.limits.memory | string | `"2Gi"` |  |
| telegraf.resources.requests.cpu | string | `"200m"` |  |
| telegraf.resources.requests.memory | string | `"400Mi"` |  |
| telegraf.securityContext.container | object | `{}` |  |
| telegraf.securityContext.pod | object | `{}` |  |
| telegraf.serviceAccount.annotations | object | `{}` |  |
| telegraf.serviceAccount.create | bool | `true` |  |
| telegraf.serviceAccount.extraLabels | object | `{}` |  |
| telegraf.serviceAccount.name | string | `""` |  |
| telegraf.shareProcessNamespace | bool | `false` |  |
| telegraf.terminationGracePeriodSeconds | int | `10` |  |
| telegraf.tolerations | list | `[]` |  |
| telegraf.topologySpreadConstraints | list | `[]` |  |
| telegraf.updateStrategyType | string | `"Recreate"` |  |